@@ -4,7 +4,7 @@ package Net::ACME;
 
 =head1 NAME
 
-Net::ACME - Client for the ACME protocol (e.g., Let’s Encrypt)
+Net::ACME - Client for the ACME protocol (e.g., L<Let’s Encrypt|http://letsencrypt.org>)
 
 =head1 SYNOPSIS
 
@@ -16,8 +16,9 @@ Net::ACME - Client for the ACME protocol (e.g., Let’s Encrypt)
 
 =head1 DESCRIPTION
 
-This module implements client logic for the ACME protocol,
-the system for automated issuance of SSL certificates used by Let’s Encrypt.
+This module implements client logic (including SSL certificate issuance)
+for the ACME protocol, the system for automated issuance of SSL
+certificates used by Let’s Encrypt.
 
 The methods of this class return objects that correspond to the
 respective ACME resource:
@@ -38,6 +39,8 @@ respective ACME resource:
 
 =item * Closely based on cPanel’s widely used Let’s Encrypt plugin.
 
+=item * Support for both RSA and ECDSA encryption (via L<Crypt::Perl>).
+
 =item * Thorough error-checking: any deviation from what the ACME protocol
 expects is reported immediately via an exception.
 
@@ -51,9 +54,8 @@ expects is reported immediately via an exception.
 (Hopefully your code isn’t susceptible to this anyway, but it’s just a good
 precaution.)
 
-=item * All dependencies are either core or pure Perl. For RSA crypto we use
-L<Crypt::OpenSSL::RSA> if it’s available, or the system’s C<openssl> binary.
-Net::ACME will run almost anywhere!
+=item * All dependencies are either core or pure Perl. Net::ACME will run
+anywhere that Perl runs!
 
 =back
 
@@ -63,11 +65,6 @@ This module is now well-tested and should be safe for use in your application.
 
 =head1 CUSTOMIZATION
 
-B<OpenSSL>: This module will attempt to use L<Crypt::OpenSSL::RSA> if it is
-available; if not, it falls back to the C<openssl> binary. On most systems this
-should already be in the process’s search path, but if not, specify the binary’s
-location by setting C<$Net::ACME::Crypt::OPENSSL_BIN_PATH>.
-
 B<HTTPS options>: This module uses C<HTTP::Tiny> for its network operations.
 In some instances it is desirable to specify custom C<SSL_options> in that
 module’s constructor; to do this, populate
@@ -131,7 +128,7 @@ See below for cut-paste-y examples.
                     last if $poll->status() eq 'valid';
 
                     if ( $poll->status() eq 'invalid' ) {
-                        my @failed = grep { $_->error() } $poll->challenges();
+                        my @failed = map { $_->error() } $poll->challenges();
 
                         warn $_->to_string() . $/ for @failed;
 
@@ -162,11 +159,12 @@ See below for cut-paste-y examples.
 
 =over 4
 
-=item * Find a way to sign with RSA in pure Perl. (NB: L<Crypt::RSA> has XS dependencies.)
-
-=item * Support EC keys.
-
-=item * Test and support more ACME v2 features (pending server support).
+=item * Once the L<ACME specification|https://tools.ietf.org/html/draft-ietf-acme-acme>
+is finalized, update this module to take advantage of the full specification.
+As Let’s Encrypt’s L<Boulder|https://github.com/letsencrypt/boulder> is currently
+the only widely-used ACME server, and that software is compatible with
+L<the first draft of the ACME spec|https://tools.ietf.org/html/draft-ietf-acme-acme-01>,
+there’s little reason to update for the time being.
 
 =back
 
@@ -177,7 +175,7 @@ See below for cut-paste-y examples.
 =item * cPanel, Inc. for permission to adapt their ACME framework for
 public consumption.
 
-=item * Stephen Ludin for developing and maintaining C<Protocol::ACME>, from which
+=item * Stephen Ludin for developing and maintaining L<Protocol::ACME>, from which
 this module took its inspiration.
 
 =back
@@ -408,7 +406,9 @@ sub do_challenge {
 
     my ( $token, $uri ) = map { $challenge_obj->$_() } qw( token uri );
 
-    $self->{'_key_jwk'} ||= Net::ACME::Utils::get_jwk_data( $self->{'_key'} );
+    my $key_obj = Net::ACME::Crypt::parse_key($self->{'_key'});
+
+    $self->{'_key_jwk'} ||= $key_obj->get_struct_for_public_jwk();
 
     my $resp = $self->_post_url(
         $uri,
